component{

	/**
	 * Configure the ColdBox App For Production
	 * https://coldbox.ortusbooks.com/getting-started/configuration
	 */
	function configure(){

		/**
		 * --------------------------------------------------------------------------
		 * ColdBox Directives
		 * --------------------------------------------------------------------------
		 * Here you can configure ColdBox for operation. Remember tha these directives below
		 * are for PRODUCTION. If you want different settings for other environments make sure
		 * you create the appropriate functions and define the environment in your .env or
		 * in the `environments` struct.
		 */
		coldbox = {
			//Application Setup
			appName 				= "Pink Unicorns Do Exist",
			reinitPassword			= "",

			//Implicit Events
			defaultEvent			= "slides.index",
			requestStartHandler		= "",
			requestEndHandler		= "",
			applicationStartHandler = "",
			applicationEndHandler	= "",
			sessionStartHandler 	= "",
			sessionEndHandler		= "",
			missingTemplateHandler	= "",

			//Error/Exception Handling
			exceptionHandler		= "",
			invalidEventHandler		= "",
			customErrorTemplate		= "",

			// Application Aspects
			handlerCaching 			= false,
			eventCaching			= false,
			autoMapModels 			= true
		};

		// environment settings, create a detectEnvironment() method to detect it yourself.
		// create a function with the name of the environment so it can be executed if that environment is detected
		// the value of the environment is a list of regex patterns to match the cgi.http_host.
		environments = {
			development = "^127\.,^localhost"
		};

		// Register interceptors as an array, we need order
		interceptors = [
		];

		//LogBox DSL
		logBox = {
			// Define Appenders
			appenders = {
				files={
					class="coldbox.system.logging.appenders.RollingFileAppender",
					properties = {
						filename = "unicorns", filePath="/#appMapping#/logs"
					}
				},
				console = {
					class="coldbox.system.logging.appenders.ConsoleAppender"
				}
			},
			// Root Logger
			root = { levelmax="DEBUG", appenders="*" },
			// Implicit Level Categories
			info = [ "coldbox.system" ]
			//debug = [ "cborm.*" ]
		};

		/**
		 * --------------------------------------------------------------------------
		 * Module Settings
		 * --------------------------------------------------------------------------
		 * Each module has it's own configuration structures, so make sure you follow
		 * the module's instructions on settings.
		 *
		 * Each key is the name of the module:
		 *
		 * myModule = {
		 *
		 * }
		 */
		moduleSettings = {
			cborm = {
				// Resource Settings
				resources : {
					// Enable the ORM Resource Event Loader
					eventLoader  : false,
					// Prefix to use on all the registered pre/post{Entity}{Action} events
					eventPrefix  : "",
					// Pagination max rows
					maxRows      : 25,
					// Pagination max row limit: 0 = no limit
					maxRowsLimit : 500
				},
				// WireBox Injection Bridge
				injection : { enabled : true, include : "", exclude : "" }
			},
			cbCodeHighlight = {
				preRenderer = true
			}
		};

	}

	/**
	* Development
	*/
	function development(){
		coldbox.handlersIndexAutoReload 	= true;
		coldbox.reinitPassword				= "";
		coldbox.customErrorTemplate 		= "/coldbox/system/exceptions/BugReport.cfm";
	}

}
